<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['%d association'] = '%d kết hợp';
$lang['%d associations'] = '%d kết hợp';
$lang['%d album including'] = '%d đề mục bao gồm ';
$lang['%d albums including'] = '%d đề mục bao gồm ';
$lang['%d physical'] = '%d physical';
$lang['%d physical'] = '%d physical';
$lang[' and %d virtual'] = ' và %d thư mục ảo';
$lang[' and %d virtual'] = ' và %d thư mục ảo';
$lang['%d album moved'] = '%d đề mục đã được chuyển';
$lang['%d albums moved'] = '%d đề mục đã được chuyển';
$lang['%d group'] = '%d nhóm';
$lang['%d groups'] = '%d nhóm';
$lang['%d member'] = '%d thành viên';
$lang['%d members'] = '%d thành viên';
$lang['%d tag'] = '%d thẻ';
$lang['%d tags'] = '%d thẻ';
$lang['%d user comment rejected'] = '%d lời bình của thành viên dùng đã bị từ chối';
$lang['%d user comments rejected'] = '%d lời bình của thành viên dùng đã bị từ chối';
$lang['%d user comment validated'] = '%d lời bình của thành viên dùng đã được xác nhận';
$lang['%d user comments validated'] = '%d lời bình của thành viên dùng đã được xác nhận';
$lang['%d user deleted'] = '%d tên thành viên đã được xóa';
$lang['%d users deleted'] = '%d tên thành viên đã được xóa';
$lang['%d user'] = '%d thành viên';
$lang['%d users'] = '%d thành viên';
$lang['%d waiting for validation'] = 'Có %d hình đang đợi xác nhận';
$lang['Actions'] = 'Hành động';
$lang['Activate'] = 'Kích hoạt';
$lang['Add/delete a permalink'] = 'Thêm/xoá một link cố định';
$lang['Add a tag'] = 'Thêm một tag';
$lang['Add a user'] = 'Thêm một thành viên';
$lang['Add group'] = 'Thêm nhóm';
$lang['Add'] = 'Thêm';
$lang['Allow user registration'] = 'Cho phép đăng ký';
$lang['Apply to sub-albums'] = 'Áp dụng cho các đề mục nhỏ';
$lang['Associated'] = 'Được kết hợp';
$lang['Batch management'] = 'Quản lý nhóm';
$lang['Caddie management'] = 'Quản lý Caddie ';
$lang['Caddie'] = 'Caddie';
$lang['Albums authorized thanks to group associations'] = 'Đề mục đã được cho phép nhờ vào kết hợp nhóm';
$lang['Album manual order was saved'] = 'Sắp xếp thủ công đề mục đã được lưu';
$lang['Check for upgrade failed for unknown reasons.'] = 'Quá trình dò tìm phiên bản nâng cấp bị lỗi, không xác định được nguyên nhân.';
$lang['Check for upgrade'] = 'Dò tìm phiên bản mới';
$lang['Comments for all'] = 'Cho mọi đối tượng được phép gởi bình luận';
$lang['Current name'] = 'Tên hiện tại';
$lang['Database'] = 'Cơ sở dữ liệu';
$lang['Deactivate'] = 'Bỏ kích hoạt';
$lang['Delete Representant'] = 'Xoá mục đại diện';
$lang['Delete selected tags'] = 'Xoá những tag đã chọn';
$lang['Delete selected users'] = 'Xoá những thành viên đã chọn';
$lang['Deletions'] = 'Xoá bỏ';
$lang['Deny selected groups'] = 'Từ chối nhóm đã chọn';
$lang['Deny selected users'] = 'Từ chối thành viên đã chọn';
$lang['Description'] = 'Miêu tả';
$lang['Display options'] = 'Hiển thị tuỳ chọn';
$lang['Dissociated'] = 'Không kết hợp';
$lang['Does not represent'] = 'Không làm đại diện';
$lang['Edit selected tags'] = 'Biên tập các tag đã chọn';
$lang['Edit tags'] = 'Biên tập tags';
$lang['Email admins when a new user registers'] = 'Gởi email cho quản trị khi có một thành viên mới đăng ký';
$lang['Email admins when a valid comment is entered'] = 'Gởi email cho quản trị khi có một lời bình đã xác nhận được gởi lên gallery.';
$lang['Email admins when a comment requires validation'] = 'Gởi email cho quản trị khi có một mời bình cần được xác nhận';
$lang['Environment'] = 'Môi trường';
$lang['Form'] = 'Form';
$lang['Gallery title'] = 'Tiêu đề của gallery';
$lang['Grant selected groups'] = 'Cấp cho các nhóm đã chọn';
$lang['Grant selected users'] = 'Cấp cho các thành viên đã chọn';
$lang['Group name'] = 'Tên nhóm';
$lang['Groups'] = 'Nhóm người dùng';
$lang['Guests'] = 'Khách';
$lang['History'] = 'Bản ghi';
$lang['Informations'] = 'Thông tin';
$lang['Install'] = 'Cài đặt';
$lang['Link all album photos to a new album'] = 'Liên kết tất cả các thành phần của đề mục này với một đề mục mới';
$lang['Link all album photos to some existing albums'] = 'Liên kết tất cả các thành phần của đề mục này với một số đề mục trước';
$lang['Linked albums'] = 'Đã liên kết các đề mục trên';
$lang['Lock gallery'] = 'Tạm khoá gallery';
$lang['Maintenance'] = 'Bảo trì';
$lang['Edit album permissions'] = 'Quản lý quyền truy xuất của một đề mục';
$lang['Manage permissions for group "%s"'] = 'Quản lý quyền truy xuất của nhóm "%s"';
$lang['Manage permissions for user "%s"'] = 'Quản lý quyền truy xuất của thành viên "%s"';
$lang['Manage tags'] = 'Quản lý tags';
$lang['Members'] = 'Thành viên';
$lang['Metadata synchronized from file'] = 'Metadata đã được đồng bộ hoá từ file';
$lang['Move albums'] = 'Di chuyển đề mục';
$lang['Move'] = 'Di chuyển';
$lang['Name'] = 'Tên';
$lang['New name'] = 'Tên mới';
$lang['New parent album'] = 'Đề mục ngoài mới';
$lang['New tag'] = 'Tag mới';
$lang['Number of comments per page'] = 'Số lời bình trên một trang';
$lang['Number of rates'] = 'Số lần đánh giá';
$lang['Number of thumbnails to create'] = 'Số hình thu nhỏ cần tạo ra';
$lang['Only private albums are listed'] = 'Chỉ những đề mục riêng tư mới được liệt kê';
$lang['Operating system'] = 'Hệ điều hành';
$lang['Options'] = 'Tuỳ chọn';
$lang['Other private albums'] = 'Các đề mục riêng tư khác';
$lang['Page banner'] = 'Banner của trang';
$lang['Parent album'] = 'Đề mục ngoài';
$lang['Path'] = 'Đường dẫn';
$lang['Permalink'] = 'Liên kết cố định';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'Có %s liên kết cố định đã được dùng trước đó bởi đề mục %s. Hãy xoá liên kết cố định này từ bảng ghi trước.';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"';
$lang['Permalink %s is already used by album %s'] = 'Liên kết cố định %s được sử dụng bởi đề mục %s';
$lang['Permalink history'] = 'Permalink history';
$lang['Permalinks'] = 'Liên kết cố định';
$lang['Permission denied'] = 'Sự chấp nhận đã bị từ chối';
$lang['Permission granted thanks to a group'] = 'Chấp nhận đã được công nhân nhờ vào một nhóm người dùng';
$lang['Permission granted'] = 'Sự chấp nhận đã được công nhận';
$lang['Photo informations updated'] = 'Thông tin của hình đã được cập nhật';
$lang['Plugins'] = 'Plugins';
$lang['Position'] = 'Vị trí';
$lang['Preferences'] = 'Tuỳ chỉnh';
$lang['Properties'] = 'Thuộc tính';
$lang['Random photo'] = 'Hình ngẫu nhiên';
$lang['Rate date'] = 'Ngày tháng đánh giá';
$lang['Rating by guests'] = 'Đánh giá bởi khách';
$lang['Rating'] = 'Đánh giá';
$lang['Reject'] = 'Từ chối';
$lang['Representant'] = 'Hình đại diện';
$lang['Representation of albums'] = 'Hình đại diện cho các đề mục';
$lang['Representative'] = 'Đại diện';
$lang['Represents'] = 'Hình đại diện';
$lang['Save order'] = 'Lưu vị trí sắp xếp';
$lang['Save to permalink history'] = 'Lưu vào bảng ghi cố định';
$lang['Select at least one album'] = 'Chọn ít nhất một đề mục';
$lang['Select at least one photo'] = 'Chọn ít nhất một hình ảnh';
$lang['Select at least one user'] = 'Chọn ít nhất một người dùng';
$lang['Show info'] = 'Hiển thị thông tin';
$lang['Site manager'] = 'Quản lý site';
$lang['Status'] = 'Trạng thái';
$lang['Statistics'] = 'Thống kê';
$lang['Storage album'] = 'Đề mục lưu trữ';
$lang['Sum of rates'] = 'Tổng hợp đánh giá';
$lang['Tag "%s" already exists'] = 'Tag "%s" đã có đó';
$lang['Tag "%s" was added'] = 'Tag "%s" đã được thêm vào';
$lang['Tag selection'] = 'Chọn tag';
$lang['The %d following tags were deleted'] = 'Các tag %d sau đã bị xoá';
$lang['Unable to check for upgrade.'] = 'Không thể dò tìm bản nâng cấp.';
$lang['Uninstall'] = 'Tháo bỏ';
$lang['Use the default photo sort order (defined in the configuration file)']='Sử dụng tính năng sắp xếp vị trí hình ảnh mặc định (được chỉ ra trong file cấu hình)';
$lang['User comments validation'] = 'Xác nhận lời bình của thành viên';
$lang['Users'] = 'Thành viên';
$lang['Validate'] = 'Xác nhận';
$lang['Validation'] = 'Xác nhận';
$lang['Version'] = 'Phiên bản';
$lang['Virtual albums to move'] = 'Đề mục ảo cần di chuyển';
$lang['Virtual album name'] = 'Tên đề mục ảo';
$lang['Webmaster cannot be deleted'] = 'Webmaster không thể xoá được';
$lang['You are running on development sources, no check possible.'] = 'Bạn đang sử dụng mã nguồn dạng phát triển, không thể kiểm tra được.';
$lang['You cannot delete your account'] = "Bạn không thể tự xoá tài khoản của mình được";
$lang['You cannot move an album in its own sub album'] = 'Bạn không thể dời một đề mục vào trong đề mục con của chính nó.';
$lang['You need to confirm deletion'] = 'Bạn cần được xác nhận để xoá';
$lang['add tags'] = 'Thêm các tags';
$lang['Associate to album'] = 'Kết hợp với đề mục';
$lang['associate to group'] = 'kết hợp với nhóm người dùng';
$lang['Authorized'] = 'Được cho phép';
$lang['Add a virtual album'] = 'Thêm vào một đề mục ảo';
$lang['Authorize users to add comments on selected albums'] = 'Cho phép người dùng có thể gởi bình luận ở các đề mục được chọn';
$lang['The name of an album must not be empty'] = 'Tên của đề mục không được để trống';
$lang['Lock albums'] = 'Những đề mục bị khoá';
$lang['Private'] = 'Đề mục riêng';
$lang['Public'] = 'Đề mục chung (công cộng)';
$lang['Find a new representant by random'] = 'Tìm ngẫu nhiên hình ảnh đại diện mới';
$lang['Public / Private'] = 'Chung / Riêng tư';
$lang['Manage authorizations for selected albums'] = 'Quản lý sự cho phép đối với những đề mục được chọn';
$lang['Virtual album added'] = 'Đề mục ảo đã được thêm vào';
$lang['Virtual album deleted'] = 'Đề mục ảo đã bị xoá';
$lang['Access type'] = 'Kiểu truy cập';
$lang['Comments'] = 'Lời bình';
$lang['Information data registered in database'] = 'Dữ liệu thông tin đã thêm vào cơ sở dữ liệu';
$lang['Default display'] = 'Hiển thị theo mặc định';
$lang['The gallery URL is not valid.'] = 'Địa chỉ của gallery không tồn tại.';
$lang['Main'] = 'Mục chính';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'Số lời bình trên một trang phải từ 5 đến 50.';
$lang['Configuration'] = 'Cấu hình';
$lang['confirm'] = 'xác nhận';
$lang['Date'] = 'Ngày tháng';
$lang['delete album'] = 'xoá bỏ đề mục';
$lang['Dissociate from album'] = 'không kết hợp với đề mục';
$lang['dissociate from group'] = 'Không kết hợp với nhóm người dùng';
$lang['edit album permissions'] = 'thay đổi quyền truy cập của đề mục';
$lang['Album updated successfully'] = 'Thông tin của đề mục đã được cập nhập thành công.';
$lang['photos per page'] = 'thành phần trên mỗi trang';
$lang['High definition enabled'] = 'Bật chế độ xem hình lớn';
$lang['File'] = 'Tệp tin';
$lang['Filesize'] = 'Cỡ file';
$lang['first photo added on %s'] = 'thành phần đầu tiên đã được thêm vào %s';
$lang['Forbidden'] = 'Bị cấm';
$lang['global mode'] = 'chế độ tổng thể';
$lang['group "%s" added'] = 'nhóm người dùng tên "%s" đã được thêm vào';
$lang['group "%s" deleted'] = 'nhóm người dùng tên "%s" đã được xoá';
$lang['group "%s" updated'] = 'nhóm người dùng tên "%s" đã được cập nhật';
$lang['group'] = 'nhóm người dùng';
$lang['The name of a group must not contain " or \' or be empty.'] = 'Tên của nhóm người dùng không có ký tự "\' hoặc bỏ trống.';
$lang['This name is already used by another group.'] = 'Tên nhóm đã được đặt cho nhóm người dùng trước đó.';
$lang['High definition'] = 'Định dạng cao';
$lang['jump to album'] = 'nhảy đến đề mục';
$lang['jump to photo'] = 'nhảy đến hình';
$lang['leave'] = 'để';
$lang['Lock'] = 'Khoá';
$lang['Locked'] = 'Đã khoá';
$lang['manage album photos'] = 'quản lý các thành phần đề mục';
$lang['manage sub-albums'] = 'quản lý các đề mục con';
$lang['Manage'] = 'Quản lý';
$lang['maximum height'] = 'Chiều cao tối đa';
$lang['maximum width'] = 'Chiều rộng tối đa';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'Thời gian xử lý đã hết, quá trình xử lý cần phải được tiếp tục [Trong khoảng: %d giây].';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'Thời gian xử lý đã hết, quá trình xử lý cần phải được tiếp tục [Trong khoảng: %d giây].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'Thời gian chuẩn bị cho danh sách người dùng cần gởi email là có giới hạn. Các thành viên khác không được liệt kê ra.';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'Thời gian gởi mail là có giới hạn. Các email khác đã được bỏ qua.';
$lang['To send ?'] = 'Để gởi ?';
$lang['Last send'] = 'Gởi lần cuối';
$lang['email'] = 'địa chỉ email';
$lang['User'] = 'Người dùng';
$lang['Complementary mail content'] = 'Nội dung email được bổ sung';
$lang['See you soon,'] = 'Hẹn gặp lại bạn,';
$lang['Go to'] = 'Đi đến ';
$lang['Hello'] = 'Xin chào ';
$lang['New photos were added'] = 'Thành phần mới đã được thêm ';
$lang['on'] = ' vào ';
$lang['between'] = 'giữa ';
$lang['and'] = ' và ';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'Webmaster đã đăng ký bạn nhận thông báo qua email.';
$lang['You have subscribed to receiving notifications by mail.'] = 'Bạn đã đăng ký nhận thông báo qua email.';
$lang['To subscribe'] = 'Đăng ký';
$lang['If you encounter problems or have any question, please send a message to'] = 'Nếu bạn bắt gặp lỗi hoặc cần hỏi điều gì liên quan đến site, vui lòng gởi email liên hệ';
$lang['[NBM] Problems or questions'] = '[NBM] Lỗi hoặc câu hỏi';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'Webmaster đã xoá email của bạn ra khỏi danh sách nhận thông báo qua email.';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'Bạn đã xoá email của mình ra khỏi danh sách nhận thông báo qua email.';
$lang[', click on'] = ', click vào ';
$lang['To unsubscribe'] = 'Không đăng ký';
$lang['With blank value, gallery title will be used'] = 'Với giá trị nhập vào để trống, thì tiêu đề của gallery sẽ được sử dụng thay thế';
$lang['Notification'] = 'Thông báo';
$lang['Error when sending email to %s [%s].'] = 'Có lỗi khi gởi email đến %s [%s].';
$lang['Mail sent to %s [%s].'] = 'Email đã được gởi tới %s [%s].';
$lang['%d mail was sent.'] = 'Có %d mail đã được gởi.';
$lang['%d mails were sent.'] = 'Có %d mails đã được gởi.';
$lang['%d mail was not sent.'] = 'Có %d mail không gởi được.';
$lang['%d mails were not sent.'] = 'Có %d mails không gởi được.';
$lang['No mail to send.'] = 'Không có mail nào được gởi đi.';
$lang['There is no available subscribers to mail.'] = 'Không có đăng ký nhận email nào.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'Người đăng ký có thể được liệt kê ra nếu như chỉ gởi thông báo khi có thành phần mới thêm vào.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'Dù sao thì chỉ có webmasters có thể xem được tab này còn đối với quản trị thì không.';
$lang['No user to send notifications by mail.'] = 'Không có người dùng nào cần gởi email thông báo.';
$lang['New photos added'] = 'Thành phần mới đã được thêm';
$lang['Subscribe to notification by mail'] = 'Đăng ký nhận thông báo qua email';
$lang['Unsubscribe from notification by mail'] = 'Bỏ đăng ký nhận thông báo qua email';
$lang['Parameter'] = 'Tham số';
$lang['Continue processing treatment'] = 'Tiếp tục quá trình xử lý';
$lang['Complementary mail content'] = 'Nội dung email bổ sung';
$lang['Add detailed content'] = 'Thêm vào nội dung chi tiết';
$lang['Send mail as'] = 'Gởi mail như';
$lang['Send mail to users'] = 'Gởi mail đến người dùng';
$lang['Send'] = 'Gởi';
$lang['Options'] = 'Tuỳ chọn';
$lang['Subscribed'] = 'Đăng ký nhận tin';
$lang['Subscribe'] = 'Đăng ký';
$lang['Parameters'] = 'Tham số';
$lang['Select recipients'] = 'Chọn người nhận';
$lang['Subscribe/unsubscribe users'] = 'Người dùng có đăng ký/bỏ đăng ký';
$lang['Unsubscribed'] = 'Bỏ đăng ký';
$lang['%d parameter was updated.'] = 'Có %d tham số đã được cập nhật.';
$lang['%d parameters were updated.'] = 'Có %d tham số đã được cập nhật.';
$lang['%d user was not updated.'] = 'Có %d người dùng không được cập nhật.';
$lang['%d users were not updated.'] = 'Có %d người dùng không được cập nhật.';
$lang['User %s [%s] was removed from the subscription list.'] = 'Người dùng %s [%s] đã được xoá khỏi danh sách đăng ký nhận tin.';
$lang['User %s [%s] was added to the subscription list.'] = 'Người dùng %s [%s] đã được thêm vào danh sách đăng ký nhận tin.';
$lang['%d user was updated.'] = 'Có %d người dùng được cập nhật.';
$lang['%d users were updated.'] = 'Có %d người dùng được cập nhật.';
$lang['User %s [%s] was not removed from the subscription list.'] = 'Người dùng %s [%s] đã không xoá khỏi danh sách đăng ký nhận tin.';
$lang['User %s [%s] was not added to the subscription list.'] = 'Người dùng %s [%s] đã không thêm vào danh sách đăng ký nhận tin.';
$lang['User %s [%s] added.'] = 'Thành viên %s [%s] đã được thêm.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'Cảnh báo: đăng ký hoặc không đăng ký gởi email đến cho các thành viên.';
$lang['Send mail on HTML format'] = 'Gởi mail với định dạng HTML';
$lang['Include display of recent photos grouped by dates'] = 'Bao gồm cả việc hiển thị những hình ảnh gần đây được nhóm lại theo ngày tháng.';
$lang['Available only with HTML format'] = 'Chỉ dùng được với định dạng HTML';
$lang['no write access'] = 'không được phép ghi';
$lang['Permissions'] = 'Quyền truy xuất';
$lang['private'] = 'riêng tư';
$lang['public'] = 'công cộng';
$lang['Purge never used notification feeds'] = 'Việc dọn dẹp hệ thống không bao giờ sử dụng các feed thông báo.';
$lang['Purge sessions'] = 'Phiên dọn dẹp';
$lang['randomly represented'] = 'đại diện ngẫu nhiên';
$lang['registration date'] = 'ngày tháng đăng ký';
$lang['clean'] = 'dọn dẹp';
$lang['remove remote listing.xml file'] = 'bỏ file truy xuất từ xa listing.xml';
$lang['generate listing'] = 'tạo ra danh sách';
$lang['generate file listing.xml on remote site'] = 'tạo ra file listing.xml trên site truy xuất từ xa';
$lang['Create this site'] = 'Khởi tạo site này';
$lang['A local listing.xml file has been found for'] = 'Một file listing.xml cục bộ đã được tìm thấy cho';
$lang['read local listing.xml and update'] = 'đọc file listing.xml cục bộ và cập nhật';
$lang['test'] = 'kiểm tra';
$lang['test this remote site'] = 'kiểm tra site truy xuất từ xa này';
$lang['remove tags'] = 'bỏ tags';
$lang['Repair and optimize database'] = 'Sửa chữa và tối ưu hóa cơ sở dữ liệu';
$lang['selection'] = 'chọn lựa';
$lang['set to'] = 'cài đặt thành';
$lang['singly represented'] = 'đại diện đơn';
$lang['This site already exists'] = 'Site này đã có trước đó';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'Tạo một site mới : (gán địa chỉ của nó vào file create_listing_file.php)';
$lang['created'] = 'đã được tạo';
$lang['delete'] = 'xóa bỏ';
$lang['delete this site and all its attached elements'] = 'xóa site này và tất cả các thành phần đính kèm';
$lang['deleted'] = 'đã xoa bỏ';
$lang['an error happened'] = 'có một lỗi xuất hiện';
$lang['file create_listing_file.php on remote site was not found'] = 'file create_listing_file.php ở trên site truy xuất từ xa không được tìm thấy';
$lang['Local'] = 'Cục bộ';
$lang['Remote'] = 'Từ xa';
$lang['synchronize'] = 'đồng bộ hóa';
$lang['update the database from files'] = 'cập nhật cơ sở dữ liệu từ file';
$lang['status'] = 'trạng thái';
$lang['Directory'] = 'Thư mục';
$lang['sub-albums'] = 'đề mục con';
$lang['synchronize metadata'] = 'đồng bộ hóa metadata';
$lang['target'] = 'mục tiêu';
$lang['Thumbnail'] = 'Hình thu nhỏ';
$lang['title'] = 'Tiêu đề';
$lang['Album list management'] = 'Quản lý đề mục';
$lang['Piwigo configuration'] = 'Cấu hình Piwigo';
$lang['Edit album'] = 'Biên tập một đề mục';
$lang['Group management'] = 'Quản lý nhóm';
$lang['User list'] = 'Danh sách thành viên';
$lang['Edit photo information'] = 'Chỉnh sửa thông tin của hình ảnh';
$lang['Thumbnail creation'] = 'Khởi tạo hình thu nhỏ';
$lang['Database synchronization with files'] = 'Đồng bộ hóa cơ sở dữ liệu với tệp tin';
$lang['all'] = 'tất cả';
$lang['photos without thumbnail (jpeg and png only)'] = 'hình ảnh không có hình thu nhỏ (chỉ áp dụng cho định dạng jpeg và png)';
$lang['height must be a number superior to'] = 'chiều cao hình phải là số lớn hơn';
$lang['width must be a number superior to'] = 'chiều rộng hình phải là số lớn hơn';
$lang['for the file format'] = 'dành cho định dạng file';
$lang['No missing thumbnail'] = 'Không thiếu hình thu nhỏ nào';
$lang['Photo unreachable or no support'] = 'Hình không đọc được hoặc định dạng không được hỗ trợ';
$lang['GD version'] = 'Phiên bản GD';
$lang['Miniaturization parameters'] = 'Tối thiểu hóa tham số';
$lang['generated in'] = 'được tạo trong';
$lang['Results of miniaturization'] = 'Kết quả tổi thiểu hóa';
$lang['General statistics'] = 'Thống kê tổng quát';
$lang['max time'] = 'thời gian lớn nhất';
$lang['average time'] = 'thời gian trung bình';
$lang['min time'] = 'thời gian nhỏ nhất';
$lang['number of miniaturized photos'] = 'số lượng hình ảnh được tối thiểu hóa';
$lang['total time'] = 'thời gian tổng cộng';
$lang['for this file format'] = 'dành cho định dạng file này';
$lang['unit mode'] = 'chế độ đơn vị hình';
$lang['Unlocked'] = 'Bỏ khóa';
$lang['unset'] = 'không đặt';
$lang['Update albums informations'] = 'Cập nhật thông tin của đề mục';
$lang['Update photos information'] = 'Cập nhật thông tin của hình ảnh';
$lang['Synchronize'] = 'Đồng bộ hóa';
$lang['reduce to single existing albums'] = 'rút gọn về đề mục đơn đang tồn tại';
$lang['Choose an option'] = 'Chọn một tùy chọn';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'hiển thi thông tin tối đa (thành phần và đề mục được thêm vào hoặc bị xóa đi)';
$lang['Piwigo version differs on the remote site'] = 'Phiên bản Piwigo không giống với phiên bản trên site truy xuất từ xa';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = 'Phiên bản file create_listing_file.php trên site truy xuất từ xa và phiên bản Piwigo phải như nhau';
$lang['listing.xml file was not found'] = 'File listing.xml không tìm thấy';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = 'File listing.xml không tìm thấy trên site truy xuất từ xa. File này được tạo ra bằng cách click vào lệnh "generate listing" trong mục Quản lý site';
$lang['Error list'] = 'Danh sách lỗi';
$lang['Errors caption'] = 'Ghi chú lỗi';
$lang['Detailed informations'] = 'Thông tin chi tiết';
$lang['File/directory read error'] = 'Lỗi đọc file/thư mục';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'Tệp tin hoặc thư mục không truy xuất được (có thê nó không tồn tại hoặc bị từ chối truy cập)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'một loại file hình ảnh yêu cầu một hình thu nhỏ. Hình thu nhỏ phải có trong thư mục con có tên là "thumbnail" của thư mục đề mục. Tên của hình thu nhỏ phải bắt đầu bằng tiền tố hình thu nhỏ đã được thiết lập và phần mở rộng phải nằm trong danh sách định dạng file cho phép ';
$lang['missing thumbnail'] = 'thiếu hình thu nhỏ';
$lang['albums deleted in the database'] = 'đã xóa các đề mục trong cơ sở dữ liệu';
$lang['photos deleted from the database'] = 'đã xóa các thành phần trong cơ sở dữ liệu';
$lang['photos candidates for metadata synchronization'] = 'hình ảnh được bình chọn cho việc đồng bộ hóa metadata';
$lang['photos informations synchronized with files metadata'] = 'thông tin những thành phần được đồng bộ hóa với metadata của file';
$lang['errors during synchronization'] = 'lỗi xuất hiện trong quá trình đồng bộ hóa';
$lang['albums added in the database'] = 'đề mục được thêm vào cơ sở dữ liệu';
$lang['photos added in the database'] = 'thành phần được thêm vào cơ sở dữ liệu';
$lang['photos updated in the database'] = 'thành phần được cập nhật vào cơ sở dữ liệu';
$lang['Search for new images in the directories'] = 'Tìm kiếm hình mới trong thư mục';
$lang['added'] = 'đã thêm vào';
$lang['deleted'] = 'đã xóa';
$lang['Metadata synchronization results'] = 'Kết quả đồng bộ hóa metadata';
$lang['only perform a simulation (no change in database will be made)'] = 'chỉ thực hiện công đoạn giả lập (không có sự thay đổi nào đối với cơ sở dữ liệu)';
$lang['[Simulation]'] = '[Giả lập]';
$lang['Simulation'] = 'Giả lập';
$lang['directories + files'] = 'thư mục + tệp tin';
$lang['only directories'] = 'chỉ áp dụng cho các thư mục';
$lang['synchronize files structure with database'] = 'đồng bộ hóa cấu trúc file với cơ sở dữ liệu';
$lang['synchronize files metadata with database photos informations'] = 'đồng bộ hóa metadata của file với thông tin các thành phần cơ sở dữ liệu';
$lang['even already synchronized photos'] = 'ngay cả những thành phần đã được đồng bộ hóa';
$lang['Used metadata'] = 'Metadata được sử dụng';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'Tên thư mục và phải là chữ hoặc số, "-", "_" hoặc "."';
$lang['wrong filename'] = 'sai tên file';
$lang['Upload'] = 'Gởi hình';
$lang['user "%s" added'] = 'thành viên "%s" đã được thêm';
$lang['User status'] = 'Trạng thái của thành viên';
$lang['user_status_admin'] = 'Quản trị';
$lang['user_status_generic'] = 'Chung';
$lang['user_status_guest'] = 'Khách';
$lang['user_status_normal'] = 'Thành viên';
$lang['user_status_webmaster'] = 'Webmaster';
$lang['Virtual album'] = 'Đề mục ảo';
$lang['Waiting'] = 'Đang đợi';
$lang['default'] = 'mặc định';
$lang['Toggle \'default group\' property'] = 'Dịch chuyển \'nhóm mặc định\' thuộc tính';
$lang['Advanced features'] = 'Đặc điểm vượt trội';
$lang['Specials'] = 'Đặc biệt';
$lang['Overall'] = 'Toàn bộ';
$lang['Year'] = 'Năm';
$lang['Month'] = 'Tháng';
$lang['Day'] = 'Ngày';
$lang['Pages seen'] = 'Những trang được xem';
$lang['Time'] = 'Thời gian';
$lang['IP'] = 'Địa chỉ IP';
$lang['Element'] = 'Thành phần';
$lang['Section'] = 'Mục';
$lang['Tags'] = 'Thẻ';
$lang['Save page visits by guests'] = 'Lưu trang đã xem bởi khách';
$lang['Save page visits by users'] = 'Lưu tra đã xem bởi người dùng';
$lang['Save page visits by administrators'] = 'Lưu trang đã xem bởi quản trị';
$lang['An information email was sent to group "%s"'] = 'Một thư thông báo đã được gởi đến nhóm người dùng "%s"';
$lang['Send an information email to group members'] = 'Gởi thư thông báo đến nhóm thành viên';
$lang['Group'] = 'Nhóm';
$lang['[%s] Visit album %s'] = '[%s] Đến để xem đề mục %s';
$lang['Hello,'] = 'Xin chào,';
$lang['See you soon.'] = 'Hẹn gặp lại bạn.';
$lang['Discover album:'] = 'Đến để khám phá đề mục:';
$lang['Mail content'] = 'Nội dung thư gởi';
$lang['none'] = 'không';
$lang['high'] = 'chiều cao';
$lang['other'] = 'khác';
$lang['Element type'] = 'Loại thành phần';
$lang['Image id'] = 'Id của hình';
$lang['Summary'] = 'Tóm tắt';
$lang['%d line filtered'] = 'Có %d hành được lọc ra';
$lang['%d lines filtered'] = 'Có %d hành được lọc ra';
$lang['%d guest'] = 'Có %d khách';
$lang['%d guests'] = 'Có %d khách';
$lang['Hour'] = 'Giờ';
$lang['guest'] = 'khách';
$lang['default values'] = 'giá trị mặc định';
$lang['High filesize'] = 'Chiều cao kích thước file';
// --------- Starting below: New or revised $lang ---- from version 1.7.1
$lang['Guest cannot be deleted'] = 'Tài khoản khách không thể bị xóa';
$lang['Default user cannot be deleted'] = 'Người dùng mặc định không thể bị xóa';
$lang['Purge history detail'] = 'Dọn dẹp bản ghi chi tiết';
$lang['Purge history summary'] = 'Dọn dẹp tóm tắt bản ghi';
$lang['Check integrity'] = 'Kiểm tra tính nguyên vẹn';
$lang['Anomaly'] = 'Bất thường';
$lang['Correction'] = 'Sửa đổi';
$lang['Automatic correction'] = 'Sửa đổi tự động';
$lang['Impossible automatic correction'] = 'Không thể sửa đổi tự động';
$lang['Correction applied with success'] = 'Sửa đổi được áp dụng với những thành công';
$lang['Correction applied with error'] = 'Sửa đổi được áp dụng với những lỗi';
$lang['%d anomaly has been detected.'] = 'Có %d bất thường được nhận dạng.';
$lang['%d anomalies have been detected.'] = 'Có %d bất thường được nhận dạng.';
$lang['%d anomaly has been corrected.'] = 'Có %d bất thường đã được sửa đổi.';
$lang['%d anomalies have been detected corrected.'] = 'Có %d bất thường đã được nhận dạng sửa đổi.';
$lang['%d anomaly has not been corrected.'] = 'Có %d bất thường không được sửa đổi.';
$lang['%d anomalies have not been corrected.'] = 'Có %d bất thường không được sửa đổi.';
$lang['Go to %s or %s for more informations'] = 'Chuyển đến %s hoặc %s để có thêm thông tin';
$lang['the forum'] = 'diễn đàn';
$lang['the wiki'] = 'thư viện wiki';
$lang['%s value is not correct file because exif are not supported'] = 'Có %s giá trị không phải là kiểu file đúng bởi vì exif không được hỗ trợ';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = 'Có %s phải được thiết lập là false trong file config_local.inc.php của bạn';
$lang['Main "guest" user does not exist'] = 'Nhóm người dùng "khách chính" không tồn tại';
$lang['Main "guest" user status is incorrect'] = 'Trạng thái nhóm người dùng "khách chính" không đúng';
$lang['Default user does not exist'] = 'Người dùng mặc định không tồn tại';
$lang['Main "webmaster" user does not exist'] = 'Nhóm "webmaster chính" không tồn tại';
$lang['Main "webmaster" user status is incorrect'] = 'Trạng thái nhóm "webmaster chính" không đúng';
$lang['User "%s" created with "%s" like password'] = 'Người dùng "%s" được tạo ra với cùng mật khẩu "%s"';
$lang['Status of user "%s" updated'] = 'Trạng thái của người dùng "%s" đã được cập nhật';
$lang['add new photos to caddie'] = 'thêm thành phần mới vào caddie';
// --------- Starting below: New or revised $lang ---- from Butterfly
$lang['No display'] = 'Không hiển thị';
$lang['Classic display'] = 'Hiển thị kiểu classic';
$lang['Hoverbox display'] = 'Hiển thị  kiểu hoverbox';
$lang['Mail address is obligatory for all users'] = 'Địa chỉ email là thành phần bắt buộc đối với mọi nhóm người dùng';
$lang['Minimum privacy level'] = 'Mức độ riêng tư tối thiểu';
$lang['Privacy level'] = 'Mức độ riêng tư';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'Liên hệ';
$lang['Level 2'] = 'Bạn bè';
$lang['Level 4'] = 'Gia đình';
$lang['Level 8'] = 'Quản trị';
$lang['Reinitialize check integrity'] = 'Tái khởi động quá trình kiểm tra tính nguyên vẹn';
$lang['Check all'] = 'Chọn tất cả';
$lang['Uncheck all'] = 'Bỏ chọn tất cả';
$lang['Check automatic corrections'] = 'Kiểm tra sửa lỗi tự động';
$lang['Apply selected corrections'] = 'Áp dụng những sửa lỗi đã chọn';
$lang['Ignore selected anomalies'] = 'Bỏ qua những bất thường đã chọn';
$lang['Refresh'] = 'Làm tươi lại';
$lang['The anomaly will be ignored until next application version'] = 'Bất thường sẽ bị bỏ qua cho đến khi phiên bản tiếp theo của ứng dụng.';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = 'Sửa đổi những bất thường sẽ hủy bỏ vấ đề chính mà nó bị bỏ qua';
$lang['%d anomaly has been ignored.'] = 'Có %d báo cáo bất thường đã được bỏ qua.';
$lang['%d anomalies have been ignored.'] = 'Có %d báo cáo bất thường đã được bỏ qua.';
$lang['Plugins which need upgrade'] = 'Plugins cần được nâng cấp';
$lang['Plugin list'] = 'Danh sách plugin';
$lang['Check for updates'] = 'Dò tìm bản bâng cấp';
$lang['Other plugins'] = 'Các plugins khác';
$lang['Last revisions'] = 'Lần sửa đổi cuối';
$lang['Delete'] = 'Xóa bỏ';
$lang['Are you sure you want to delete this plugin?'] = 'Bạn có chắc là muốn xóa bỏ plugin này không?';
$lang['Are you sure you want to install this plugin?'] = 'Bạn có chắc là muốn cài đặt plugin này không?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'Bạn có chắc là muốn cài đặt bản nâng cấp này? Bạn phải xác nhận nếu phiên bản này không yêu cầu phải tháo bỏ phiên bản cũ.';
$lang['%s has been successfully upgraded.'] = 'Plugin tên %s đã được nâng cấp thành công.';
$lang['Plugin has been successfully copied'] = 'Plugin đã được copy xong';
$lang['You might go to plugin list to install and activate it.'] = 'Bạn nen vào danh sách các plugin để cài đặt và kích hoạt nó.';
$lang['Can\'t create temporary file.'] = 'Không thể tạo ra file tạm.';
$lang['Can\'t download archive.'] = 'Không thể tải xuống tệp lưu trữ.';
$lang['Can\'t read or extract archive.'] = 'Không thể đọc hoặc trích xuất tệp lưu trữ.';
$lang['An error occured during extraction (%s).'] = 'Có lỗi xuất hiện trong quá trình trích xuất (%s).';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'Vui lòng kiểm tra quyền truy xuất của thư mục "plugins" và thư mục con (CHMOD).';
$lang['Can\'t connect to server.'] = 'Không thể kết nối với máy chủ.';
$lang['Purge compiled templates'] = 'Don dẹp những template kết hợp';
$lang['ACCESS_0'] = 'Truy xuất tự to';
$lang['ACCESS_1'] = 'Truy xuất vào tất cả';
$lang['ACCESS_2'] = 'Truy xuất vào mục đăng ký nhân bản tin';
$lang['ACCESS_3'] = 'Truy xuất vào phần quản trị';
$lang['ACCESS_4'] = 'Truy xuất vào webmasters';
$lang['ACCESS_5'] = 'Không được phép truy xuất';
$lang['Support'] = 'Hỗ trợ';
$lang['Documentation'] = 'Tài liệu tham khảo';
$lang['A new version of Piwigo is available.'] = 'Đã có phiên bản Piwigo mới.';
$lang['Piwigo Administration'] = 'Quản trị Piwigo';
$lang['Piwigo version'] = 'Phiên bản Piwigo';
$lang['You are running the latest version of Piwigo.'] = 'Bạn đang sử dụng phiên bản mới nhất của Piwigo.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'Phiên bản %s [%s] đã cài đặt không tương thích với phiên bản được yêu cầu là [%s]';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'Bạn cần nâng cấp hệ thống để tận dụng hết các chức năng của ứng dụng, nếu không ứng dụng sẽ không hoạt động chính xác, hoặc sẽ không vận hành được';
$lang['Deleted on'] = 'Xóa vào';
$lang['Last hit'] =  'Lần xem cuối';
$lang['GD library is missing'] = 'Thư viện GD bị thiếu';
$lang['Templates'] = 'Templates';
$lang['Extend for templates'] = 'Mở rộng cho template';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = 'Việc thay đổi các templates gốc bằng những templates tùy biến từ thư mục con chứa thành phần template mở rộng';
$lang['Replacers (customized templates)'] = 'Thay thế (templates được tùy biến)';
$lang['Original templates'] = 'Templates gốc';
$lang['Optional URL keyword'] = 'Từ khóa URL tùy chọn';
$lang['Templates configuration has been recorded.'] = 'Cầu hình tempalte đã được ghi.';
$lang['All optimizations have been successfully completed.'] = 'Tất cả quá trình tối ưu hóa đã hoàn thành xong.';
$lang['Optimizations have been completed with some errors.'] = 'Quá trình tối ưu hóa đã hoàn thành với một vài lỗi.';
$lang['Modify information'] = 'Hiệu chỉnh thông tin';
$lang['edit album'] = 'biên tập thông tin đề mục';
$lang['nothing'] = 'không có gì';
$lang['overrides existing values with empty ones'] = 'ghi đè giá trị đang tồn tại bằng giá trị rỗng';
$lang['manage photo ranks'] = 'Quản lý xếp hạng hình ảnh';
$lang['Manage photo ranks'] = 'Quản lý xếp hạng hình ảnh';
$lang['Edit ranks'] = 'Biên tập xếp hạng';
$lang['No photo in this album'] = 'Không có thành phần nào trong đề mục này';
$lang['Images manual order was saved'] = 'Sắp xếp hình ảnh thủ công đã được lưu';
$lang['ranks'] = 'xếp hạng';
$lang['Drag to re-order'] = 'Kéo rê để sắp xếp lại';
$lang['Quick Local Synchronization'] = 'Đồng bộ hóa cục bộ nhanh';
$lang['No photo can be deleted'] = 'Không có hình nào có thể bị xóa';
$lang['Delete selected photos'] = 'Xóa các hình được chọn';
$lang['%d photo was deleted'] = '%d hình đã được xóa';
$lang['%d photos were deleted'] = 'Có %d hình đã được xóa';
$lang['Downloads'] = 'Tải xuống';
$lang['Released on'] = 'Phát hành vào';
$lang['Number of downloads'] = 'Số lần download';
// --------- Starting below: New or revised $lang ---- from Colibri
$lang['Piwigo Announcements Newsletter'] = 'Bản tin Piwigo';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = 'Giữ liên lạc với Piwigo Project, đăng ký nhận bản tin từ Piwigo. Bạn sẽ nhận được email mỗi khi phiên bản mới được phát hành (đôi khi cũng bao gồm bản sửa lỗi, cần thiết để biết và cập nhật) và khi sự kiện chính xảy ra đối với dự án. Chỉ có vài email trong một năm.';
$lang['Subscribe %s'] = 'Đăng ký nhận tin %s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'Đăng ký %s nhận bản tin của Piwigo';
$lang['Purge search history'] = 'Dọn dẹp bản ghi tìm kiếm';
$lang['Hide'] = 'Ẩn';
$lang['Menu Management'] = 'Trình đơn';
$lang['Operation in progress'] = 'Đang tiến hành xử lý.';
$lang['Please wait...'] = 'Vui lòng đợi...';
$lang['By rank'] = 'Theo hạng';
$lang['Manual order'] = 'Sắp xếp thủ công';
$lang['Password is missing. Please enter the password.'] = 'Thiếu mật khẩu. Vui lòng nhập mật khẩu.';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'Xác nhận mật khẩu bị thiếu. Vui lòng xác nhận lại mật khẩu đã chọn.';
$lang['Password confirmation error.'] = 'Lỗi xác nhận mật khẩu.';
$lang['Allow users to edit their own comments'] = 'Cho phép người dùng chỉnh sửa lời bình luận riêng của họ';
$lang['Allow users to delete their own comments'] = 'Cho phép người dùng xóa lời bình luận riêng của họ';
$lang['Email administrators when a comment is modified'] = 'Gởi email cho Quản trị viên có một lời bình luận được chỉnh sửa';
$lang['Email administrators when a comment is deleted'] = 'Gởi email cho Quản trị viên có một lời bình luận bị xóa';
$lang['Cannot delete the old permalink !'] = 'Liên kết cố định cũ thì không thể bị xóa!';
$lang['Hit'] = 'Lần xem';
$lang['Tools'] = 'Công cụ';
$lang['Photos'] = 'Ảnh';
$lang['Themes'] = 'Giao diện';
$lang['Instructions to use Piwigo'] = 'Hướng dẫn sử dụng Piwigo';
$lang['Installed Themes'] = 'Giao diện đã được cài đặt';
$lang['Add New Theme'] = 'Thêm một giao diện mới';
$lang['Forbid this theme to users'] = 'Cấm người dùng sử dụng giao diện này';
$lang['Set as default theme for unregistered and new users'] = 'Đặt làm giao diện mặt định cho tất cả người dùng chưa đăng ký và thành viên mới';
$lang['unknown'] = 'không xác định';
$lang['Upload Photos'] = 'Tải ảnh lên';
$lang['Drop into album'] = 'Chuyển vào đề mục';
$lang['+ Add an upload box'] = '+ Thêm một mục gởi hình ';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Tạo ra "%s" thư mục ở cùng thư mục cài đặt Piwigo của bạn';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Gán quyền được ghi (chmod 777) cho "%s" thư mục ở cùng thư mục cài đặt Piwigo của bạn';
$lang['existing album'] = 'đề mục hiện có';
$lang['create a new album'] = 'tạo một đề mục mới';
$lang['Album name'] = 'Tên đề mục';
$lang['Album "%s" has been added'] = 'Đề mục "%s" đã được thêm vào';
$lang['Uploaded Photos'] = 'Ảnh đã được gởi lên';
$lang['%d photos uploaded'] = 'Đã có %d ảnh được gởi';
$lang['Privacy level set to "%s"'] = 'Mức độ riêng tư đã được thiết lập ở mức "%s"';
$lang['Album "%s" now contains %d photos'] = 'Đề mục "%s" hiện tại chứa %d bức ảnh';
$lang['Manage this set of %d photos'] = 'Quản lý bộ gồm %d ảnh';
$lang['Select files'] = 'Chọn tệp tin';
$lang['Everybody'] = 'Mọi người';
$lang['Who can see these photos?'] = 'Ai có thể xem được những bức ảnh này?';
$lang['Who can see this photo?'] = 'Ai có thể xem được bức ảnh này?';
$lang['The websize maximum width must be a number between %d and %d'] = 'Chiều rộng lớn nhất của trang web phải là số nằm giữa %d và %d';
$lang['The websize maximum height must be a number between %d and %d'] = 'Chiều cao lớn nhất của trang web phải là số nằm giữa %d và %d';
$lang['The websize image quality must be a number between %d and %d'] = 'Chất lượng hình của trang web phải là số nằm giữa %d và %d';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'Chiều rộng hình thu nhỏ lớn nhất phải là số nằm giữa %d và %d';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'Chiều cao hình thu nhỏ lớn nhất phải là số nằm giữa %d và %d';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'Chất lượng hình thu nhỏ phải là số nằm giữa %d và %d';
$lang['Settings'] = 'Cài đặt';
$lang['Web size photo'] = 'Ảnh có kích cỡ web';
$lang['Resize'] = 'Định dạng lại kích thước';
$lang['Maximum Width'] = 'Chiều rộng lớn nhất';
$lang['pixels'] = 'pixels';
$lang['Maximum Height'] = 'Chiều cao lớn nhất';
$lang['Image Quality'] = 'Chất lượng hình';
$lang['Save Settings'] = 'Lưu cài đặt';
$lang['Your configuration settings are saved'] = 'Thiết lập cấu hình của bạn đã được lưu';
$lang['Active Themes'] = 'Kích hoạt giao diện';
$lang['Add write access to the "%s" directory'] = 'Gán quyền được ghi cho thư mục "%s"';
$lang['Administration Home'] = 'Trang chủ của Quản trị';
$lang['Change Admin Colors'] = 'Thay đổi màu trang Quản trị';
$lang['Delete this theme'] = 'Xóa giao diện này';
$lang['Directory does not exist'] = 'Thư mục không tồn tại';
$lang['Download,'] = 'Tải xuống,';
$lang['FTP + Synchronization'] = 'FTP + Đồng bộ hóa';
$lang['Get Support on Piwigo Forum'] = 'Nhận hỗ trợ từ diễn đàn Piwigo';
$lang['Help Me'] = 'Xin giúp tôi';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'Giao diện này không thể kích hoạt được, một khi giao diện chủ bị thiếu: %s';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Giao diện này không thể bị xóa bởi vì có một hay một vài giao diện khác phụ thuộc vào nó: %s';
$lang['Inactive Themes'] = 'Giao diện không được kích hoạt';
$lang['Install on your computer,'] = 'Cài đặt trên máy của bạn,';
$lang['Make this theme available to users'] = 'Thiết lập cho những tài khoản người dùng có thể sử dụng được';
$lang['Page end'] = 'Kết thúc trang';
$lang['Piwigo Uploader'] = 'Công cụ gởi hình Piwigo';
$lang['Read Piwigo Documentation'] = 'Tham khảo tài liệu về Piwigo';
$lang['Start pLoader and add your photos.'] = 'Bắt đầu sử dụng pLoader và gởi ảnh của bạn.';
$lang['Switch to clear or dark colors for administration'] = 'Chuyển sang màu sáng hoặc tối đối với Quản trị viên';
$lang['Theme has been successfully installed'] = 'Giao diện đã được cài đặt thành công';
$lang['Visit Gallery'] = 'Ghé xem thư viện hình';
$lang['Visit Piwigo project website'] = 'Ghé vào trang chủ của Dự án Piwigo';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'Công cụ pLoader là một <em>công cụ gởi ảnh của Piwigo</em>. Từ máy tính của bạn, pLoader sẽ chuẩn bị các bước thiết lập cho những bức ảnh và chuyển chúng lên thư viện ảnh Piwigo của bạn.';
$lang['Guest Settings'] = 'Thiết lập cho tài khoản khách';
$lang['Main Page'] = 'Trang chính';
$lang['Photo Page'] = 'Trang ảnh';
$lang['Activate Navigation Bar'] = 'Kích hoạt thanh điều hướng trang';
$lang['Activate Navigation Thumbnails'] = 'Kích hoạt hình thu nhỏ điều hướng trang';
$lang['Activate icon "%s"'] = 'Kích hoạt biểu tượng "%s"';
$lang['Activate field "%s"'] = 'Kích hoạt trường "%s"';
$lang['Photo Properties'] = 'Thuộc tính ảnh';
$lang['Allow user customization'] = 'Cho phép người dùng tùy biến ';
$lang['Languages'] = 'Ngôn ngữ';
$lang['Installed Languages'] = 'Gói ngôn ngữ đã được cài';
$lang['Add New Language'] = 'Thêm gói ngôn ngữ mới';
$lang['Language has been successfully installed'] = 'Gói ngôn ngữ đã được cài đặt thành công';
$lang['Select:'] = 'Chọn:';
$lang['None'] = 'Không';
$lang['Invert'] = 'Đảo ngược';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Không thể vô hiệu hóa giao diện này, bạn cần ít nhất một giao diện.';
$lang['Webmaster status is required.'] = 'Trạng thái của Webmaster cần phải có.';
$lang['Bound Theme'] = 'Giao diện biên';
$lang['Allow rating'] = 'Cho phép xếp hạng';
$lang['Select at least one comment'] = 'Chọn ít nhất một lời bình';
$lang['Active Plugins'] = 'Plugin đang sử dụng';
$lang['Inactive Plugins'] = 'Plugin không được sử dụng';
$lang['Missing Plugins'] = 'Plugin bị thiếu';
$lang['Uninstalled Plugins'] = 'Plugin đã được gỡ bỏ';
$lang['By %s'] = 'Bởi %s';
$lang['Visit plugin site'] = 'Xem trang web chứa plugin';
$lang['Active Languages'] = 'Ngôn ngữ hiện đang sử dụng';
$lang['Delete this language'] = 'Xóa gói ngôn ngữ này';
$lang['Forbid this language to users'] = 'Cấm người dùng sử dụng gói ngôn ngữ này.';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Không thể tắt gói ngôn ngữ này, trước tiên cần phải thiết lập gói ngôn ngữ mặc định khác.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'Không thể tắt gói ngôn ngữ này, bạn cần ít nhất một gói ngôn ngữ.';
$lang['Inactive Languages'] = 'Ngôn ngữ hiện không sử dụng';
$lang['Make this language available to users'] = 'Thiết lập cho phép sử dụng gói ngôn ngữ này cho mọi người dùng.';
$lang['Set as default language for unregistered and new users'] = 'Thiết lập là ngôn ngữ mặc định cho nhóm người dùng mới và nhóm chưa đăng ký.';
$lang['Add Photos'] = 'Thêm ảnh';
$lang['Download'] = 'Tải xuống';
$lang['The following tag was deleted'] = 'Thẻ sau đây đã bị xóa';
$lang['Miscellaneous'] = 'Linh tinh';
$lang['Virtual Links'] = 'Liên kết ảo';
$lang['There is no other language available.'] = 'Không có gói ngôn ngữ nào có thể dùng được.';
$lang['There is no other plugin available.'] = 'Không có plugin nào có thể dùng được.';
$lang['There is no other theme available.'] = 'Không có gói giao diện nào có thể dùng được.';
$lang['Add another set of photos'] = 'Thêm vào bộ ảnh khác';
$lang['Order of menubar items has been updated successfully.'] = 'Vị trí của các mục trong thanh menubar đã được cập nhật thành công.';
$lang['This theme was not designed to be directly activated'] = 'Giao diện này không được thiết kế để có thể kích hoạt trực tiếp';
$lang['Pending Comments'] = 'Lời bình đang chờ';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'Trong tệp tin php.ini, biến upload_max_filesize (%sB) thì lớn hơn biến post_max_size (%sB), bạn nên thay đổi thiết lập này';
$lang['Exif extension not available, admin should disable exif use'] = 'Nếu phần mở rộng Exif không tồn tại thì Quản trị viên nên vô hiệu hóa việc sử dụng Exif';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'Tệp tin gởi lên đã vượt quá giá trị hướng dẫn của biến upload_max_filesize ở tệp tin php.ini: %sB';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Tệp tin gởi lên đã vượt quá giá trị hướng dẫn của biến post_max_size ở tệp tin php.ini: %sB';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'Tệp tin gởi lên đã vượt quá giá trị hướng dẫn của biến MAX_FILE_SIZE đã được định ra trong form HTML';
$lang['The uploaded file was only partially uploaded'] = 'Tệp tin gởi lên chỉ được gởi một phần (không hoàn chỉnh)';
$lang['No file was uploaded'] = 'Không có tệp tin nào được gởi lên';
$lang['Missing a temporary folder'] = 'Còn thiếu một thư mục tạm';
$lang['Failed to write file to disk'] = 'Bị lỗi khi ghi tệp tin lên đĩa';
$lang['File upload stopped by extension'] = 'Quá trình gởi tệp tin đã dừng lại bởi phần mở rộng của tệp tin';
$lang['Unknown upload error'] = 'Lỗi gởi hình không xác định được';
$lang['Error on file "%s" : %s'] = 'Có lỗi ở tệp tin "%s" : %s';
$lang['automatic order'] = 'sắp xếp tự động';
$lang['manual order'] = 'sắp xếp thủ công';
$lang['Albums automatically sorted'] = 'Albums đã được phân loại tự động';
$lang['Keep high definition'] = 'Giữ nguyên định dạng cao';
$lang['The high definition maximum width must be a number between %d and %d'] = 'Chiều rộng lớn nhất của định dạng cao phải là số trong khoảng %d và %d';
$lang['The high definition maximum height must be a number between %d and %d'] = 'Chiều cao lớn nhất của định dạng cao phải là số trong khoảng %d và %d';
$lang['The high definition image quality must be a number between %d and %d'] = 'Chất lượng ảnh của định dang cao phải là số trong khoảng %d và %d';
$lang['Batch Manager'] = 'Quản lý khối';
$lang['include child albums'] = 'bao gồm các albums con';
$lang['Selection'] = 'Lựa chọn';
$lang['Action'] = 'Thực thi';
$lang['Set author'] = 'Thiết lập tác giả';
$lang['Set title'] = 'Thiết lập tiêu đề';
$lang['Set creation date'] = 'Thiết lập ngày tháng khởi tạo';
$lang['Apply action'] = 'Xác nhận thay đổi';
$lang['on the %d selected photos'] = 'trên %d hình được chọn';
$lang['%d of %d photos selected'] = '%d trong %d hình được chọn';
$lang['No photo selected, %d photos in current set'] = 'Không có hình nào được chọn, có %d hình trong bộ hiện tại';
$lang['All %d photos are selected'] = 'Tất cả %d hình đều được chọn';
$lang['remove this filter'] = 'bỏ bộ lọc này';
$lang['predefined filter'] = 'xác định trước bộ lọc';
$lang['last import'] = 'lần nhập hình cuối';
$lang['with no virtual album'] = 'với không album nào';
$lang['duplicates'] = 'trùng';
$lang['Add a filter'] = 'thêm bộ lọc';
$lang['Remove all filters'] = 'Bỏ tất cả các bộ lọc';
$lang['Refresh photo set'] = 'Cập nhật bộ hình';
$lang['The whole page'] = 'Nguyên cả trang';
$lang['The whole set'] = 'Nguyên cả bộ';
$lang['No photo in the current set.'] = 'Không có hình nào trong bộ hiện tại.';
$lang['No photo selected, no action possible.'] = 'Không có hình nào được chọn, không tác vụ nào được thực hiện.';
$lang['Choose an action'] = 'Chọn một tác vụ';
$lang['remove author'] = 'bỏ tác giả';
$lang['Type here the author name'] = 'Nhập tên tác giả vào đây';
$lang['remove title'] = 'bỏ tiêu đề';
$lang['Type here the title'] = 'Nhập tiêu đề vào đây';
$lang['remove creation date'] = 'bỏ ngày tháng khởi tạo';
$lang['with no album'] = 'với không album hình nào';
$lang['with no tag'] = 'với không thẻ nào';
$lang['Album photos associated to the following albums: %s'] = 'Ảnh được kết hợp với những albums sau: %s';
$lang['Delete orphan tags'] = 'Xóa các thẻ riêng lẽ';
$lang['delete photo'] = 'xóa ảnh';
$lang['Orphan tags deleted'] = 'Thẻ riêng lẽ đã được xóa';
$lang['Week starts on'] = 'Tuần lễ bắt đầu vào';
$lang['You have %d orphan tags: %s.'] = 'Bạn có %d thẻ riêng lẽ: %s.';
$lang['Remove from caddie'] = 'Bỏ ra khỏi caddie';
$lang['Themes which need upgrade'] = 'Giao diện cần bản nâng cấp';
$lang['Languages which need upgrade'] = 'Ngôn ngữ cần nâng cấp';
$lang['All themes are up to date.'] = 'Tất cả giao diện đều được cập nhật.';
$lang['All plugins are up to date.'] = 'Tất cả plugins đều được cập nhật.';
$lang['All languages are up to date.'] = 'Tất cả ngôn ngữ đều được cập nhật.';
$lang['Visit theme site'] = 'Đến trang web của giao diện';
$lang['Visit language site'] = 'Đến trang web của của ngôn ngữ';
$lang['New Version'] = 'Phiên bản Mới';
$lang['Obsolete Plugins'] = 'Những plugins đã cũ';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'CẢNH BÁO! Plugin này có thể không tương thích với phiên bản Piwigo hiện tại.';
$lang['Do you want to activate anyway?'] = 'Bạn vẫn muốn kích hoạt?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'PLUGIN NÀY GIỜ LÀ MỘT PHẦN CỦA NHÂN PIWIGO! GỠ BỎ NGAY!';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'LỖI: PLUGIN NÀY BỊ THIẾU NHƯNG NÓ ĐÃ ĐƯỢC CÀI ĐẶT! GỠ BỎ NGAY.';
$lang['Regenerate Thumbnails'] = 'Khởi tạo lại Hình thu nhỏ';
$lang['Thumbnails generation in progress...'] = 'Quá trình khởi tạo hình thu nhỏ đang được thực hiện...';
$lang['%s thumbnails have been regenerated'] = 'Có %s hình thu nhỏ đã được tạo ra';
$lang['%s thumbnails can not be regenerated'] = 'Có %s hình thu nhỏ không thể tạo ra được';
$lang['Regenerate Websize Photos'] = 'Khởi tạo Ảnh Web';
$lang['Photos generation in progress...'] = 'Quá trình khởi tạo ảnh web đang được thực hiện...';
$lang['%s photos have been regenerated'] = 'có %s ảnh đã được tạo ra';
$lang['%s photos can not be regenerated'] = 'Có %s ảnh không thể tạo ra được';
$lang['new'] = 'mới';
$lang['No results'] = 'Không có kết quả nào';
$lang['Searching...'] = 'Đang tìm kiếm...';
$lang['Type in a search term'] = 'Nhập vào trong mục tìm kiếm';
$lang['display'] = 'hiển thị';
$lang['Deactivate all'] = 'Bỏ kích hoạt tất cả';
$lang['Restore'] = 'Phục hồi';
$lang['Restore default configuration. You will lose your plugin settings!'] = 'Khôi phục lại cấu hình mặc định. Các thiết lập cho plugin sẽ bị mất!';
$lang['Show menubar'] = 'Hiển thị thanh trình đơn';
$lang['Updates'] = 'Bản cập nhật';
$lang['Update in progress... Please wait.'] = 'Đang tiến hành cập nhật... Vui lòng đợi.';
$lang['Ignore this update'] = 'Bỏ qua bản cập nhật này';
$lang['Reset ignored updates'] = 'Cài đặt lại những bản cập nhật đã bỏ qua';
$lang['Update All'] = 'Cập nhật Tất cả';
$lang['ERROR'] = 'CÓ LỖI';
$lang['Update Complete'] = 'Cập nhật Hoàn thành';
$lang['Piwigo Update'] = 'Cập nhật Piwigo';
$lang['Extensions Update'] = 'Cập nhật thành phần mở rộng';
$lang['All extensions are up to date.'] = 'Tất cả thành phần mở rộng đều được cập nhật.';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Plugins sau đây có thể không tương thích với phiên bản mới của Piwigo:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Giao diện sau đây có thể không tương thích với phiên bản mới của Piwigo:';
$lang['I decide to update anyway'] = 'Dù gì tôi cũng quyết định cập nhật';
$lang['Update to Piwigo %s'] = 'Cập nhật Piwigo lên phiên bản %s';
$lang['Two updates are available'] = 'Có hai bản cập nhật';
$lang['This is a minor update, with only bug corrections.'] = 'Đây là bản nâng cấp phụ, với các bản sửa lỗi.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Đây là bản cập nhật chính, với nhiều <a href="%s">tính năng mới thú vị</a>.';
$lang['Some themes and plugins may be not available yet.'] = 'Một số giao diện và plugins có thể chưa sử dụng được.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Bạn có thể cập nhật trực tiếp Piwigo lên phiên bản %s, mà không cần phải nâng cấp lên phiên bản %s (khuyến cáo).';
$lang['Save Template Directory'] = 'Lưu thư mục khuôn mẫu';
$lang['Dump Database'] = 'Kết xuất Cơ sở dữ liệu';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Bao gồm dữ liệu lược sử (Cảnh báo: giới hạn bộ nhớ máy chủ có thể bị vượt quá)';
$lang['Unable to write new local directory.'] = 'Không thể ghi vào thư mục cục bộ mới.';
$lang['Unable to send template directory.'] = 'Không thể gửi đi thư mục khuôn mẫu.';
$lang['Unable to dump database.'] = 'Không thể kết xuất cơ sở dữ liệu.';
$lang['Some upgrades are available for extensions.'] = 'Một số bản nâng cấp có thể áp dụng được cho các thành phần mở rộng.';
$lang['Ignore All'] = 'Bỏ qua Tất cả';
$lang['Crop'] = 'Xén';
$lang['Width'] = 'Chiều rộng';
$lang['Height'] = 'Chiều cao';
$lang['Follow Orientation'] = 'Định hướng Dõi theo';
$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Nếu bạn muốn tái tạo lại các hình thu nhỏ, hãy trỏ đến mục <a href="%s">Quản lý Khối</a>.';
$lang['Graphics Library'] = 'Thư viện Đồ họa';
$lang['Activate icon "new" next to albums and pictures'] = 'Kích hoạt biểu tượng "ảnh mới" kế bên albums ảnh và hình';
$lang['Add a criteria'] = 'Thêm một tiêu chí';
$lang['Default photos order'] = 'Thứ tự ảnh mặc định';
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Bạn không thể định ra một thứ tự ảnh mặc định vì đã có một thiết lập tùy chọn trong cấu hình cục bộ.';
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Bạn đã định ra <i>$conf[\'order_by\']</i> trong tệp tin cấu hình cục bộ của bạn, tham số này không được chấp nhận, hãy xóa bỏ hoặc đổi tên trong mục <i>$conf[\'order_by_custom\']</i> !';
$lang['Average rate'] = 'Xếp hạng trung bình';
$lang['Rate'] = 'Xếp hạng';
$lang['... or '] = '... hoặc ';
$lang['Create'] = 'Khởi tạo';
$lang['Start Upload'] = 'Bắt đầu Tải lên';
$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Bạn hiện đang dùng Flash Uploader. Nếu có trục trặc? Thì dùng <a href="%s">Web Uploader</a> thay thế.';
$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Bạn hiện đang dùng Browser uploader. Hãy dùng <a href="%s">Flash uploader</a> thay thế.';
$lang['Maximum file size: %sB.'] = 'Kích thước file lớn nhất: %sB.';
$lang['Allowed file types: %s.'] = 'Loại file cho phép dùng: %s.';
$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Độ phân giải lớn nhất ước chừng: %dM pixels (đó là %dx%d pixels).';
$lang['Manage Permissions'] = 'Quản lý Quyền Hạn';
$lang['Learn more'] = 'Tìm hiểu thêm';
$lang['Photo %s of %s'] = 'Ảnh %s của %s';
$lang['show details'] = 'hiện chi tiết';
$lang['hide details'] = 'ẩn chi tiết';
$lang['Merge tags'] = 'Sáp nhập nhãn';
$lang['Select the destination tag'] = 'Chọn nhãn đích';
$lang['(this tag will be deleted)'] = '(nhãn này sẽ bị xóa)';
$lang['Confirm merge'] = 'Xác nhận sáp nhập';
$lang['Merge selected tags'] = 'Sáp nhập những thẻ được chọn';
$lang['No destination tag selected'] = 'Không có nhãn đích nào được chọn';
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Nhãn <em>%s</em> được sáp nhập vào nhãn <em>%s</em>';
$lang['Select at least two tags for merging'] = 'Chọn ít nhất hai nhãn để sáp nhập';
$lang['Select an album'] = 'Chọn một album ảnh';
$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Theo mặc định, Piwigo sẽ tạo ra một kích thước web từ ảnh định dạng cao của bản.';
$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Nếu không có định dạng cao nào và nếu kích thước web hiện tại lớn hơn kích thước đã điều chỉnh, Piwigo sẽ chuyển nó thành định dạng cao và tạo ra một ảnh có kích thước web đã thu nhỏ từ ảnh gốc.';
$lang['An error has occured during upgrade.'] = 'Có một lỗi xuất hiện trong quá trình nâng cấp.';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Có một lỗi xuất hiện trong quá trình trích xuất tệp tin. Vui lòng kiểm tra quyền hiệu chỉnh tệp tin gói cài đặt Piwigo của bạn.<br><a href="%s">Click vào đây để xem lỗi.</a>.';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo không thể nhận được tệp tin nâng cấp từ  máy chủ';

?>